"""Public storefront routes."""

from django.urls import path

from ..views import storefront as views

app_name = "storefront"

urlpatterns = [
    path("<slug:slug>/item/<int:listing_id>/", views.item_detail, name="item"),
    path("<slug:slug>/bpc/<int:listing_id>/", views.bpc_detail, name="bpc_item"),
    path(
        "<slug:slug>/module/<int:listing_id>/", views.module_detail, name="module_item"
    ),
    path(
        "<slug:slug>/fitted/<int:listing_id>/", views.fitted_detail, name="fitted_item"
    ),
    path("<slug:slug>/login/", views.login, name="login"),
    path("<slug:slug>/logout/", views.logout, name="logout"),
    path("<slug:slug>/order/", views.submit_order, name="submit_order"),
    path("<slug:slug>/<str:section>/", views.section_view, name="section"),
    path("<slug:slug>/", views.detail, name="detail"),
]
