{% load i18n %}
{# Search box for a [data-table] scope; the controller (backoffice_tables.js) wires it. #}
<div class="input-group input-group-sm mb-2" style="max-width: 22rem;">
    <span class="input-group-text"><i class="fa-solid fa-magnifying-glass"></i></span>
    <input type="search" class="form-control" data-table-search autocomplete="off"
           placeholder="{{ placeholder }}">
</div>
