{% extends 'shop/base.html' %}
{% load i18n %}

{% block content %}
<div class="d-flex justify-content-between align-items-center mb-3">
    <h2 class="m-0">{% trans "My Shops" %}</h2>
    <a href="{% url 'backoffice:create' %}" class="btn btn-primary">
        <i class="fas fa-plus fa-fw"></i> {% trans "Create shop" %}
    </a>
</div>
{% include 'shop/_shop_table.html' with shops=personal_shops %}

{% if can_manage_corp %}
<h2 class="mt-5 mb-3">{% trans "Corporation Shops" %}</h2>
{% include 'shop/_shop_table.html' with shops=corp_shops %}
{% endif %}
{% endblock %}
