{% load i18n %}
{% if sections|length > 1 %}
<nav class="flex gap-2 border-b border-base-content/10 mb-6 -mt-2">
    {% for key, label in sections %}
    <a href="{% url 'storefront:section' shop.slug key %}"
       class="px-4 py-3 text-base font-semibold border-b-2 -mb-px transition
              {% if key == section %}border-primary text-base-content{% else %}border-transparent text-base-content/50 hover:text-base-content{% endif %}">
        {{ label }}
    </a>
    {% endfor %}
</nav>
{% endif %}
