{% extends 'storefront/base.html' %}
{% load i18n %}
{% block content %}
{% if is_preview %}
<div role="alert" class="mb-6 rounded-lg border border-warning/40 bg-warning/10 px-4 py-3 text-sm text-warning">
    {% trans "Unpublished — only managers can see this preview." %}
</div>
{% endif %}
{% if shop.description_html %}
<div class="shop-description relative overflow-hidden mb-8 rounded-xl bg-base-200/60 border border-base-300 border-l-4 border-l-warning p-6">
    <img src="https://images.evetech.net/types/35827/render?size=512" alt="" aria-hidden="true" class="shop-description__bg">
    <div class="shop-description__body relative">{{ shop.description_html }}</div>
</div>
{% endif %}
{% include 'storefront/_section_tabs.html' %}
{% block section_content %}{% endblock %}
{% endblock %}
