# Generated by Django 5.2.14 on 2026-07-07 14:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0026_fitted_ships'),
    ]

    operations = [
        migrations.AddField(
            model_name='fittedlisting',
            name='description',
            field=models.TextField(blank=True, default=''),
        ),
        migrations.AddField(
            model_name='fittedlisting',
            name='persist',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='fittedlisting',
            name='stock',
            field=models.PositiveIntegerField(default=1),
        ),
    ]
