"""Admin registrations."""

from django.contrib import admin

from .models import Shop


@admin.register(Shop)
class ShopAdmin(admin.ModelAdmin):
    list_display = (
        "name",
        "slug",
        "shop_type",
        "is_published",
        "corporation",
        "created_by",
    )
    list_filter = ("shop_type", "is_published")
    search_fields = ("name", "slug")
