{% extends 'shop/base.html' %}
{% load i18n %}
{% block content %}
{% include 'shop/_manage_header.html' with active='manage' %}
{% include 'shop/_section_tabs.html' %}
<div class="card"><div class="card-body text-center text-muted py-5">
    <p class="h5">{% trans "Coming soon" %}</p>
    <p class="mb-0">{% trans "This section isn't open yet." %}</p>
</div></div>
{% endblock %}
