{% extends 'storefront/section_base.html' %}
{% load i18n %}

{% block section_content %}
{% if featured_listings or grouped_listings %}
    {% trans "Search hulls…" as search_placeholder %}
    {% if view == 'table' %}
        <div data-table data-page-size="25" data-table-style="tailwind" data-table-hidden-class="hidden">
            {% include 'storefront/_section_toolbar.html' with search_placeholder=search_placeholder search_width="sm:w-[calc(33.333%_-_0.667rem)]" table_search=True %}
            {% include 'storefront/_hulls_table.html' %}
            <nav data-table-pager class="mt-3"></nav>
        </div>
    {% else %}
        {% include 'storefront/_section_toolbar.html' with search_placeholder=search_placeholder search_width="sm:w-[calc(33.333%_-_0.667rem)]" %}
        {% include 'storefront/_hulls_featured.html' %}
        {% include 'storefront/_hulls_grid.html' %}
        <p data-search-empty class="hidden py-12 text-center text-base-content/50">{% trans "No hulls match your search." %}</p>
    {% endif %}
{% else %}
<div class="rounded-xl bg-base-200 border border-base-300 p-10 text-center text-base-content/60">
    {% trans "No items listed yet." %}
</div>
{% endif %}
{% endblock %}
