# Generated by Django 5.2.14 on 2026-07-07 16:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0028_orderline_fit_json'),
    ]

    operations = [
        migrations.AddField(
            model_name='fittedlisting',
            name='miss_count',
            field=models.PositiveIntegerField(default=0),
        ),
    ]
