# Generated by Django 5.2.14 on 2026-07-07 15:29

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('shop', '0027_fitted_persist_description'),
    ]

    operations = [
        migrations.AddField(
            model_name='orderline',
            name='fit_json',
            field=models.JSONField(blank=True, default=dict),
        ),
    ]
