# Generated by Django 5.2.14 on 2026-07-07 08:08

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0012_alter_evebloodline_eve_ship_type'),
        ('shop', '0001_squashed_0025'),
    ]

    operations = [
        migrations.AddField(
            model_name='shopsource',
            name='name_filter',
            field=models.CharField(blank=True, default='', max_length=100),
        ),
        migrations.AddField(
            model_name='shopsource',
            name='strip_marker',
            field=models.BooleanField(default=True),
        ),
        migrations.CreateModel(
            name='FittedListing',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('featured', models.BooleanField(default=False)),
                ('featured_at', models.DateTimeField(blank=True, null=True)),
                ('item_id', models.BigIntegerField()),
                ('ship_name', models.CharField(blank=True, default='', max_length=255)),
                ('price', models.PositiveBigIntegerField(default=0)),
                ('fit_json', models.JSONField(blank=True, default=dict)),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('eve_type', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='+', to='eveuniverse.evetype')),
                ('shop', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='fitted_listings', to='shop.shop')),
            ],
            options={
                'constraints': [models.UniqueConstraint(fields=('shop', 'item_id'), name='uniq_shop_fitted_item')],
            },
        ),
    ]
