{% extends 'storefront/base.html' %}
{% load i18n %}
{% block content %}
<div class="rounded-xl bg-base-200 border border-base-300 p-12 text-center text-base-content/60">
    {% trans "No sections yet." %}
</div>
{% endblock %}
