{% load i18n %}
<form method="post" action="{% url 'backoffice:toggle_featured' shop.pk section listing.pk %}" class="d-inline">
    {% csrf_token %}
    <button type="submit" class="btn btn-sm btn-link p-0 ms-1 align-middle"
            title="{% if listing.featured %}{% trans 'Unstar' %}{% else %}{% trans 'Star (feature on storefront)' %}{% endif %}">
        <i class="{% if listing.featured %}fa-solid fa-star text-warning{% else %}fa-regular fa-star text-muted{% endif %}"></i>
    </button>
</form>
