{% load i18n %}
<div class="rounded-xl bg-base-200 border border-base-300 p-12 text-center">
    <p class="text-lg font-semibold">{% trans "Coming soon" %}</p>
    <p class="text-base-content/50 mt-1">{% trans "This section isn't open yet." %}</p>
</div>
