{% load i18n %}
<ul class="nav nav-tabs mb-3">
    {% for key, label in sections %}
    <li class="nav-item">
        <a class="nav-link {% if key == section %}active{% endif %}"
           href="{% url 'backoffice:manage_section' shop.pk key %}">{{ label }}</a>
    </li>
    {% endfor %}
</ul>
