{% load i18n %}
{% if order.status == 'pending' %}<span class="badge bg-secondary">{% trans "Pending" %}</span>
{% elif order.status == 'accepted' %}<span class="badge bg-info">{% trans "Accepted" %}</span>
{% elif order.status == 'completed' %}<span class="badge bg-success">{% trans "Completed" %}</span>
{% elif order.status == 'declined' %}<span class="badge bg-danger">{% trans "Declined" %}</span>
{% else %}<span class="badge bg-secondary">{% trans "Cancelled" %}</span>{% endif %}
