from django.apps import AppConfig


class ShopConfig(AppConfig):
    name = "shop"
    label = "shop"
    verbose_name = "Shop"

    def ready(self):
        from .sections import load_handlers

        load_handlers()
