{% extends 'shop/base.html' %}
{% load i18n %}
{% load django_bootstrap5 %}

{% block content %}
{% if is_edit %}
{% include 'shop/_manage_header.html' with active='edit' %}
<div class="alert alert-warning">{% trans "Changing the slug changes this shop's public URL." %}</div>
{% else %}
<h2 class="mb-3">{% trans "Create shop" %}</h2>
{% endif %}

<div class="card col-lg-6">
    <div class="card-body">
        <form method="post">
            {% csrf_token %}
            {% bootstrap_form form %}
            <div class="mt-3">
                <button type="submit" class="btn btn-primary">{% trans "Save" %}</button>
                <a href="{% url 'backoffice:index' %}" class="btn btn-secondary">{% trans "Cancel" %}</a>
            </div>
        </form>
    </div>
</div>
{% endblock %}
