{% extends 'shop/base.html' %}
{% load i18n %}
{% block content %}
{% include 'shop/_manage_header.html' with active='manage' %}
<div class="alert alert-info">{% trans "Enable a section on this shop to manage it." %}</div>
{% endblock %}
